@@ -46,16 +46,19 @@ extern "C" {
  * @{
  */
 
-#define AUTH_PASS_LEN		(7 * 16) /* multiple of 16 */
+#define AUTH_PASS_LEN		(8 * 16) /* multiple of 16 */
 #define AUTH_ID_LEN		64
 
 #define RC_BUFFER_LEN		8192
 
 #define RC_NAME_LENGTH		32
 
-#define MAX_SECRET_LENGTH	(6 * 16) /* MUST be multiple of 16 */
+#define MAX_SECRET_LENGTH	(16 * 16) /* MUST be multiple of 16 */
 
+#define RADCLI_VENDOR_MASK 0xffffffff
 #define VENDOR_BIT_SIZE		32
+#define RADCLI_VENDOR_ATTR_SET(attr, vendor) ((attr)|((uint64_t)((vendor)&RADCLI_VENDOR_MASK)) << VENDOR_BIT_SIZE)
+
 #define VENDOR(x)		(((x) >> VENDOR_BIT_SIZE) & 0xffffffff)
 #define ATTRID(x)		((x) & 0xffffffff)
 
@@ -487,7 +490,7 @@ typedef struct send_data /* Used to pass information to sendserver() function */
 {
 	uint8_t        code;		//!< RADIUS packet code.
 	uint8_t        seq_nbr;		//!< Packet sequence number.
-	char           *server;		//!< Name/addrress of RADIUS server.
+	char           *server;		//!< Name/address of RADIUS server.
 	int            svc_port;	//!< RADIUS protocol destination port.
 	char           *secret;		//!< Shared secret of RADIUS server.
 	int            timeout;		//!< Session timeout in seconds.
